% For use with Matlab
% Copyright (C) 2019 -- Jérôme Mendes <jermendes@gmail.com> or <jermendes@isr.uc.pt>, Rui Araújo <rui@isr.uc.pt>
% Jérôme Mendes, Francisco Souza, Rui Araújo, and Saeid Rastegar. "Neo-fuzzy neuron learning using backfitting algorithm". Neural Computing and Application, 2018.
% The "GAM-ZOTS toolbox" comes with ABSOLUTELY NO WARRANTY;
% In case of publication of any application of this method, please, cite the work:
% Jérôme Mendes, Francisco Souza, Rui Araújo, and Saeid Rastegar. 
% Neo-fuzzy neuron learning using backfitting algorithm.
% Neural Computing and Applications, 31(8):3609-3618, August 2019.
% DOI: https://doi.org/10.1007/s00521-017-3301-4
% http://www.isr.uc.pt/~jermendes/    ;     http://www.isr.uc.pt/~rui/

%% Clean everything
clc
clear
close all
warning('off')

tic

%% configuration file
ParametersConfig 

%% Configuration of the Dataset
DatasetConfig
        
%% Choose the best number of rules from the candidate ones (n_rules_to_train)
n_rules_best = C_BestNumberRules(n_rules_to_train, data_ytrain, data_xtrain,  limit_it, limit_theta, dataTotal_x,per_extra);

%% Learning algorithm
x = C_FAM ( data_ytrain, data_xtrain, limit_it, limit_theta, dataTotal_x, per_extra, n_rules_best);

%% Estimation - Train
y_train_est = FinalyModel_C(x, data_xtrain);
error_train = nrmse(data_ytrain, y_train_est');% normalized root-mean-squared error - NRMSE

%% Estimation - Test
y_test_est = FinalyModel_C(x, data_xtest);
error_test = nrmse(data_ytest, y_test_est');% normalized root-mean-squared error - NRMSE

toc

%% Plots
PlotMFs(x) % Plots of the membership functions

Final_Plots % Plots of the train and test results


